from braintree.amex_express_checkout_card import AmexExpressCheckoutCard as AmexExpressCheckoutCard
from braintree.android_pay_card import AndroidPayCard as AndroidPayCard
from braintree.apple_pay_card import ApplePayCard as ApplePayCard
from braintree.credit_card import CreditCard as CreditCard
from braintree.europe_bank_account import EuropeBankAccount as EuropeBankAccount
from braintree.masterpass_card import MasterpassCard as MasterpassCard
from braintree.payment_method import PaymentMethod as PaymentMethod
from braintree.paypal_account import PayPalAccount as PayPalAccount
from braintree.samsung_pay_card import SamsungPayCard as SamsungPayCard
from braintree.unknown_payment_method import UnknownPaymentMethod as UnknownPaymentMethod
from braintree.us_bank_account import UsBankAccount as UsBankAccount
from braintree.venmo_account import VenmoAccount as VenmoAccount
from braintree.visa_checkout_card import VisaCheckoutCard as VisaCheckoutCard

def parse_payment_method(gateway, attributes): ...



from typing import Any

from braintree.configuration import Configuration as Configuration

class WebhookTesting:
    @staticmethod
    def sample_notification(kind, id, source_merchant_id: Any | None = ...): ...



from typing import Any

from braintree.address import Address as Address
from braintree.configuration import Configuration as Configuration
from braintree.credit_card_verification import CreditCardVerification as CreditCardVerification
from braintree.resource import Resource as Resource

class CreditCard(Resource):
    class CardType:
        AmEx: str
        CarteBlanche: str
        ChinaUnionPay: str
        DinersClubInternational: str
        Discover: str
        Electron: str
        Elo: str
        Hiper: str
        Hipercard: str
        JCB: str
        Laser: str
        UK_Maestro: str
        Maestro: str
        MasterCard: str
        Solo: str
        Switch: str
        Visa: str
        Unknown: str

    class CustomerLocation:
        International: str
        US: str

    class CardTypeIndicator:
        Yes: str
        No: str
        Unknown: str
    Commercial: Any
    DurbinRegulated: Any
    Debit: Any
    Healthcare: Any
    CountryOfIssuance: Any
    IssuingBank: Any
    Payroll: Any
    Prepaid: Any
    ProductId: Any
    @staticmethod
    def create(params: Any | None = ...): ...
    @staticmethod
    def update(credit_card_token, params: Any | None = ...): ...
    @staticmethod
    def delete(credit_card_token): ...
    @staticmethod
    def expired(): ...
    @staticmethod
    def expiring_between(start_date, end_date): ...
    @staticmethod
    def find(credit_card_token): ...
    @staticmethod
    def from_nonce(nonce): ...
    @staticmethod
    def create_signature(): ...
    @staticmethod
    def update_signature(): ...
    @staticmethod
    def signature(type): ...
    is_expired: Any
    billing_address: Any
    subscriptions: Any
    verification: Any
    def __init__(self, gateway, attributes): ...
    @property
    def expiration_date(self): ...
    @property
    def masked_number(self): ...



from typing import Any

from braintree.error_result import ErrorResult as ErrorResult
from braintree.exceptions.not_found_error import NotFoundError as NotFoundError
from braintree.oauth_credentials import OAuthCredentials as OAuthCredentials
from braintree.successful_result import SuccessfulResult as SuccessfulResult

class OAuthGateway:
    gateway: Any
    config: Any
    def __init__(self, gateway) -> None: ...
    def create_token_from_code(self, params): ...
    def create_token_from_refresh_token(self, params): ...
    def revoke_access_token(self, access_token): ...
    def connect_url(self, raw_params): ...



from typing import Any

from braintree.add_on_gateway import AddOnGateway as AddOnGateway
from braintree.address_gateway import AddressGateway as AddressGateway
from braintree.apple_pay_gateway import ApplePayGateway as ApplePayGateway
from braintree.client_token_gateway import ClientTokenGateway as ClientTokenGateway
from braintree.configuration import Configuration as Configuration
from braintree.credit_card_gateway import CreditCardGateway as CreditCardGateway
from braintree.credit_card_verification_gateway import CreditCardVerificationGateway as CreditCardVerificationGateway
from braintree.customer_gateway import CustomerGateway as CustomerGateway
from braintree.discount_gateway import DiscountGateway as DiscountGateway
from braintree.dispute_gateway import DisputeGateway as DisputeGateway
from braintree.document_upload_gateway import DocumentUploadGateway as DocumentUploadGateway
from braintree.merchant_account_gateway import MerchantAccountGateway as MerchantAccountGateway
from braintree.merchant_gateway import MerchantGateway as MerchantGateway
from braintree.oauth_gateway import OAuthGateway as OAuthGateway
from braintree.payment_method_gateway import PaymentMethodGateway as PaymentMethodGateway
from braintree.payment_method_nonce_gateway import PaymentMethodNonceGateway as PaymentMethodNonceGateway
from braintree.paypal_account_gateway import PayPalAccountGateway as PayPalAccountGateway
from braintree.plan_gateway import PlanGateway as PlanGateway
from braintree.settlement_batch_summary_gateway import SettlementBatchSummaryGateway as SettlementBatchSummaryGateway
from braintree.subscription_gateway import SubscriptionGateway as SubscriptionGateway
from braintree.testing_gateway import TestingGateway as TestingGateway
from braintree.transaction_gateway import TransactionGateway as TransactionGateway
from braintree.transaction_line_item_gateway import TransactionLineItemGateway as TransactionLineItemGateway
from braintree.us_bank_account_gateway import UsBankAccountGateway as UsBankAccountGateway
from braintree.us_bank_account_verification_gateway import UsBankAccountVerificationGateway as UsBankAccountVerificationGateway
from braintree.webhook_notification_gateway import WebhookNotificationGateway as WebhookNotificationGateway
from braintree.webhook_testing_gateway import WebhookTestingGateway as WebhookTestingGateway

class BraintreeGateway:
    config: Any
    add_on: Any
    address: Any
    apple_pay: Any
    client_token: Any
    credit_card: Any
    customer: Any
    discount: Any
    dispute: Any
    document_upload: Any
    graphql_client: Any
    merchant: Any
    merchant_account: Any
    oauth: Any
    payment_method: Any
    payment_method_nonce: Any
    paypal_account: Any
    plan: Any
    settlement_batch_summary: Any
    subscription: Any
    testing: Any
    transaction: Any
    transaction_line_item: Any
    us_bank_account: Any
    us_bank_account_verification: Any
    verification: Any
    webhook_notification: Any
    webhook_testing: Any
    def __init__(self, config: Any | None = ..., **kwargs) -> None: ...



from typing import Any

from braintree.resource import Resource as Resource

class AndroidPayCard(Resource):
    is_expired: Any
    subscriptions: Any
    def __init__(self, gateway, attributes) -> None: ...
    @property
    def expiration_date(self): ...
    @property
    def last_4(self): ...
    @property
    def card_type(self): ...



from typing import Any

from braintree.document_upload import DocumentUpload as DocumentUpload
from braintree.error_result import ErrorResult as ErrorResult
from braintree.resource import Resource as Resource
from braintree.successful_result import SuccessfulResult as SuccessfulResult

class DocumentUploadGateway:
    gateway: Any
    config: Any
    def __init__(self, gateway) -> None: ...
    def create(self, params: Any | None = ...): ...



from typing import Any

from braintree.attribute_getter import AttributeGetter as AttributeGetter

class TransactionDetails(AttributeGetter):
    amount: Any
    def __init__(self, attributes) -> None: ...



from braintree.attribute_getter import AttributeGetter as AttributeGetter
from braintree.configuration import Configuration as Configuration
from braintree.resource import Resource as Resource

class TransactionLineItem(AttributeGetter):
    class Kind:
        Credit: str
        Debit: str
    def __init__(self, attributes) -> None: ...
    @staticmethod
    def find_all(transaction_id): ...



from typing import Any

from braintree.error_result import ErrorResult as ErrorResult
from braintree.exceptions.not_found_error import NotFoundError as NotFoundError
from braintree.resource_collection import ResourceCollection as ResourceCollection
from braintree.successful_result import SuccessfulResult as SuccessfulResult
from braintree.us_bank_account_verification import UsBankAccountVerification as UsBankAccountVerification
from braintree.us_bank_account_verification_search import UsBankAccountVerificationSearch as UsBankAccountVerificationSearch

class UsBankAccountVerificationGateway:
    gateway: Any
    config: Any
    def __init__(self, gateway) -> None: ...
    def confirm_micro_transfer_amounts(self, verification_id, amounts): ...
    def find(self, verification_id): ...
    def search(self, *query): ...



from setuptools import setup

name = "types-braintree"
description = "Typing stubs for braintree"
long_description = '''
## Typing stubs for braintree

This is a PEP 561 type stub package for the `braintree` package.
It can be used by type-checking tools like mypy, PyCharm, pytype etc. to check code
that uses `braintree`. The source for this package can be found at
https://github.com/python/typeshed/tree/master/stubs/braintree. All fixes for
types and metadata should be contributed there.

See https://github.com/python/typeshed/blob/master/README.md for more details.
This package was generated from typeshed commit `8cac5284ae8414ac57abe3758d462c5f4e78cd5e`.
'''.lstrip()

setup(name=name,
      version="4.15.0",
      description=description,
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/python/typeshed",
      project_urls={
          "GitHub": "https://github.com/python/typeshed",
          "Changes": "https://github.com/typeshed-internal/stub_uploader/blob/main/data/changelogs/braintree.md",
          "Issue tracker": "https://github.com/python/typeshed/issues",
          "Chat": "https://gitter.im/python/typing",
      },
      install_requires=[],
      packages=['braintree-stubs'],
      package_data={'braintree-stubs': ['__init__.pyi', 'account_updater_daily_report.pyi', 'ach_mandate.pyi', 'add_on.pyi', 'add_on_gateway.pyi', 'address.pyi', 'address_gateway.pyi', 'amex_express_checkout_card.pyi', 'android_pay_card.pyi', 'apple_pay_card.pyi', 'apple_pay_gateway.pyi', 'apple_pay_options.pyi', 'attribute_getter.pyi', 'authorization_adjustment.pyi', 'bin_data.pyi', 'braintree_gateway.pyi', 'client_token.pyi', 'client_token_gateway.pyi', 'configuration.pyi', 'connected_merchant_paypal_status_changed.pyi', 'connected_merchant_status_transitioned.pyi', 'credentials_parser.pyi', 'credit_card.pyi', 'credit_card_gateway.pyi', 'credit_card_verification.pyi', 'credit_card_verification_gateway.pyi', 'credit_card_verification_search.pyi', 'customer.pyi', 'customer_gateway.pyi', 'customer_search.pyi', 'descriptor.pyi', 'disbursement.pyi', 'disbursement_detail.pyi', 'discount.pyi', 'discount_gateway.pyi', 'dispute.pyi', 'dispute_details/__init__.pyi', 'dispute_details/evidence.pyi', 'dispute_details/paypal_message.pyi', 'dispute_details/status_history.pyi', 'dispute_gateway.pyi', 'dispute_search.pyi', 'document_upload.pyi', 'document_upload_gateway.pyi', 'environment.pyi', 'error_codes.pyi', 'error_result.pyi', 'errors.pyi', 'europe_bank_account.pyi', 'exceptions/__init__.pyi', 'exceptions/authentication_error.pyi', 'exceptions/authorization_error.pyi', 'exceptions/braintree_error.pyi', 'exceptions/configuration_error.pyi', 'exceptions/gateway_timeout_error.pyi', 'exceptions/http/__init__.pyi', 'exceptions/http/connection_error.pyi', 'exceptions/http/invalid_response_error.pyi', 'exceptions/http/timeout_error.pyi', 'exceptions/invalid_challenge_error.pyi', 'exceptions/invalid_signature_error.pyi', 'exceptions/not_found_error.pyi', 'exceptions/request_timeout_error.pyi', 'exceptions/server_error.pyi', 'exceptions/service_unavailable_error.pyi', 'exceptions/too_many_requests_error.pyi', 'exceptions/unexpected_error.pyi', 'exceptions/upgrade_required_error.pyi', 'facilitated_details.pyi', 'facilitator_details.pyi', 'granted_payment_instrument_update.pyi', 'iban_bank_account.pyi', 'ids_search.pyi', 'local_payment.pyi', 'local_payment_completed.pyi', 'local_payment_reversed.pyi', 'masterpass_card.pyi', 'merchant.pyi', 'merchant_account/__init__.pyi', 'merchant_account/address_details.pyi', 'merchant_account/business_details.pyi', 'merchant_account/funding_details.pyi', 'merchant_account/individual_details.pyi', 'merchant_account/merchant_account.pyi', 'merchant_account_gateway.pyi', 'merchant_gateway.pyi', 'modification.pyi', 'oauth_access_revocation.pyi', 'oauth_credentials.pyi', 'oauth_gateway.pyi', 'paginated_collection.pyi', 'paginated_result.pyi', 'partner_merchant.pyi', 'payment_instrument_type.pyi', 'payment_method.pyi', 'payment_method_gateway.pyi', 'payment_method_nonce.pyi', 'payment_method_nonce_gateway.pyi', 'payment_method_parser.pyi', 'paypal_account.pyi', 'paypal_account_gateway.pyi', 'paypal_here.pyi', 'plan.pyi', 'plan_gateway.pyi', 'processor_response_types.pyi', 'resource.pyi', 'resource_collection.pyi', 'revoked_payment_method_metadata.pyi', 'risk_data.pyi', 'samsung_pay_card.pyi', 'search.pyi', 'settlement_batch_summary.pyi', 'settlement_batch_summary_gateway.pyi', 'signature_service.pyi', 'status_event.pyi', 'subscription.pyi', 'subscription_details.pyi', 'subscription_gateway.pyi', 'subscription_search.pyi', 'subscription_status_event.pyi', 'successful_result.pyi', 'testing_gateway.pyi', 'three_d_secure_info.pyi', 'transaction.pyi', 'transaction_amounts.pyi', 'transaction_details.pyi', 'transaction_gateway.pyi', 'transaction_line_item.pyi', 'transaction_line_item_gateway.pyi', 'transaction_search.pyi', 'unknown_payment_method.pyi', 'us_bank_account.pyi', 'us_bank_account_gateway.pyi', 'us_bank_account_verification.pyi', 'us_bank_account_verification_gateway.pyi', 'us_bank_account_verification_search.pyi', 'util/__init__.pyi', 'util/constants.pyi', 'util/crypto.pyi', 'util/datetime_parser.pyi', 'util/generator.pyi', 'util/graphql_client.pyi', 'util/http.pyi', 'util/parser.pyi', 'util/xml_util.pyi', 'validation_error.pyi', 'validation_error_collection.pyi', 'venmo_account.pyi', 'version.pyi', 'visa_checkout_card.pyi', 'webhook_notification.pyi', 'webhook_notification_gateway.pyi', 'webhook_testing.pyi', 'webhook_testing_gateway.pyi', 'METADATA.toml']},
      license="Apache-2.0 license",
      classifiers=[
          "License :: OSI Approved :: Apache Software License",
          "Programming Language :: Python :: 3",
          "Typing :: Stubs Only",
      ]
)



from typing import Any

from braintree.exceptions.configuration_error import ConfigurationError as ConfigurationError

class Environment:
    __name__: Any
    is_ssl: Any
    ssl_certificate: Any
    def __init__(
        self, name, server, port, auth_url, is_ssl, ssl_certificate, graphql_server: str = ..., graphql_port: str = ...
    ) -> None: ...
    @property
    def base_url(self): ...
    @property
    def port(self): ...
    @property
    def auth_url(self): ...
    @property
    def protocol(self): ...
    @property
    def server(self): ...
    @property
    def server_and_port(self): ...
    @property
    def graphql_server(self): ...
    @property
    def graphql_port(self): ...
    @property
    def graphql_server_and_port(self): ...
    @staticmethod
    def parse_environment(environment): ...
    @staticmethod
    def braintree_root(): ...
